==> com.ibm.jbatch.container-1.0.2-sources.jar: com/ibm/jbatch/container/util/PartitionDataWrapper.java <==
/**
 * Copyright 2013 International Business Machines Corp.
 *
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership. Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ibm.jbatch.container.util;

import java.io.Serializable;

import javax.batch.runtime.BatchStatus;

public class PartitionDataWrapper {
    
    private Serializable collectorData;

    private BatchStatus batchStatus;
    
    private String exitStatus;
    
    private PartitionEventType eventType;

    public enum PartitionEventType { ANALYZE_COLLECTOR_DATA, ANALYZE_STATUS }
    
    public BatchStatus getBatchstatus() {
        return batchStatus;
    }

    public void setBatchStatus(BatchStatus batchStatus) {
        this.batchStatus = batchStatus;
    }

    public String getExitStatus() {
        return exitStatus;
    }

    public void setExitStatus(String exitStatus) {
        this.exitStatus = exitStatus;
    }

    public Serializable getCollectorData() {
        return collectorData;
    }

    public void setCollectorData(Serializable collectorData) {
        this.collectorData = collectorData;
    }

    public PartitionEventType getEventType() {
        return eventType;
    }

    public void setEventType(PartitionEventType eventType) {
        this.eventType = eventType;
    }
    
}

==> com.ibm.jbatch.container-2.1.1-sources.jar: com/ibm/jbatch/container/util/PartitionDataWrapper.java <==
/**
 * Copyright 2013 International Business Machines Corp.
 *
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership. Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ibm.jbatch.container.util;

import java.io.Serializable;

import jakarta.batch.runtime.BatchStatus;

public class PartitionDataWrapper {
    
    private Serializable collectorData;

    private BatchStatus batchStatus;
    
    private String exitStatus;
    
    private PartitionEventType eventType;

    public enum PartitionEventType { ANALYZE_COLLECTOR_DATA, ANALYZE_STATUS }
    
    public BatchStatus getBatchstatus() {
        return batchStatus;
    }

    public void setBatchStatus(BatchStatus batchStatus) {
        this.batchStatus = batchStatus;
    }

    public String getExitStatus() {
        return exitStatus;
    }

    public void setExitStatus(String exitStatus) {
        this.exitStatus = exitStatus;
    }

    public Serializable getCollectorData() {
        return collectorData;
    }

    public void setCollectorData(Serializable collectorData) {
        this.collectorData = collectorData;
    }

    public PartitionEventType getEventType() {
        return eventType;
    }

    public void setEventType(PartitionEventType eventType) {
        this.eventType = eventType;
    }
    
}
